//! This module contains implementations of `Dummy` trait

#[cfg(feature = "base64")]
pub mod base64;
#[cfg(feature = "bigdecimal-rs")]
pub mod bigdecimal;
#[cfg(feature = "bson_oid")]
pub mod bson_oid;
#[cfg(feature = "chrono")]
pub mod chrono;
#[cfg(feature = "chrono-tz")]
pub mod chrono_tz;
#[cfg(feature = "random_color")]
pub mod color;
#[cfg(feature = "rust_decimal")]
pub mod decimal;
#[cfg(feature = "email_address")]
pub mod email_address;
#[cfg(feature = "geo-types")]
pub mod geo;
#[cfg(feature = "glam")]
pub mod glam;
#[cfg(feature = "http")]
pub mod http;
#[cfg(feature = "indexmap")]
pub mod indexmap;
#[cfg(feature = "semver")]
pub mod semver;
#[cfg(feature = "serde_json")]
pub mod serde_json;
pub mod std;
#[cfg(feature = "time")]
pub mod time;
#[cfg(feature = "ulid")]
pub mod ulid;
#[cfg(feature = "url")]
pub mod url;
#[cfg(feature = "uuid")]
pub mod uuid;
#[cfg(feature = "zerocopy")]
pub mod zerocopy_byteorder;
